parabolic
=========

Time stepping method for parabolic problems.

|CircleCI| |codecov| |PyPi Version| |GitHub stars|

Testing
~~~~~~~

To run the tests, check out this repository and type

::

    pytest

License
~~~~~~~

parabolic is published under the MIT license. See the file LICENSE for
detailed information.

.. |CircleCI| image:: https://img.shields.io/circleci/project/github/nschloe/parabolic.svg
   :target: https://circleci.com/gh/nschloe/parabolic
.. |codecov| image:: https://codecov.io/gh/nschloe/parabolic/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/nschloe/parabolic
.. |PyPi Version| image:: https://img.shields.io/pypi/v/parabolic.svg
   :target: https://pypi.python.org/pypi/parabolic
.. |GitHub stars| image:: https://img.shields.io/github/stars/nschloe/parabolic.svg?style=social&label=Star&maxAge=2592000
   :target: https://github.com/nschloe/parabolic
